@@ -33,7 +33,8 @@ def analysis_reaction_network_enrichment(self,
                                          plot_scores: bool = True,
                                          plot_n_col: int = 3,
                                          plot_fig_size: Tuple[int, int] = (10, 18),
-                                         plot_hspace: float = 0.4
+                                         plot_hspace: float = 0.4,
+                                         correct_n_lipids: bool = True
                                          ) -> Tuple[Dict[str, nx.Graph],
                                                     Dict[str, List[float]],
                                                     Dict[str, float],
@@ -131,11 +132,21 @@ def analysis_reaction_network_enrichment(self,
             mapped_products = list(set([reverse_mapping[x] for x in products]))
 
             if difference_as_change:
-                tmp_ratio = sum([user_data[x] for x in mapped_products]) - sum(
-                    [user_data[x] for x in mapped_substrates])
+                if correct_n_lipids:
+                    tmp_ratio = np.mean([user_data[x] for x in mapped_products], axis=0) - np.mean(
+                        [user_data[x] for x in mapped_substrates], axis=0)
+                    tmp_ratio = pd.Series(tmp_ratio, index=user_data[mapped_products[0]].index)
+                else:
+                    tmp_ratio = sum([user_data[x] for x in mapped_products]) - sum(
+                        [user_data[x] for x in mapped_substrates])
             else:
-                tmp_ratio = math.prod([user_data[x] for x in mapped_products]) / \
-                            math.prod([user_data[x] for x in mapped_substrates])
+                if correct_n_lipids:
+                    product_prod = math.prod([user_data[x] for x in mapped_substrates]) ** (1 / len(mapped_substrates))
+                    substrate_prod = math.prod([user_data[x] for x in mapped_products]) ** (1 / len(mapped_products))
+                    tmp_ratio = product_prod / substrate_prod
+                else:
+                    tmp_ratio = math.prod([user_data[x] for x in mapped_products]) / \
+                                math.prod([user_data[x] for x in mapped_substrates])
 
             # Join with group labels
             tmp_ratio_df = pd.DataFrame({"r": tmp_ratio}).join(pd.DataFrame({"groups": self.groups}))
@@ -434,7 +445,8 @@ def _ratio_distributions_(
     difference_dist: bool = False,
     reference_group: str = "",
     as_boxplot: bool = False,
-    as_subplots: bool = True
+    as_subplots: bool = True,
+    z_scores: bool = False
 ) -> Tuple[plt.Figure, Dict[str, pd.DataFrame]]:
     # Extract all reactions classes for reaction_type != L_FAmodify (only class reactions)
     if fa_specific:
@@ -516,7 +528,8 @@ def _ratio_distributions_(
                            plot_fig_size=plot_fig_size,
                            plot_hspace=plot_hspace,
                            difference_dist=difference_dist,
-                           as_subplots=as_subplots)
+                           as_subplots=as_subplots,
+                           z_scores=z_scores)
     else:
         fig = plot_histogram(data_for_hist,
                              plot_n_col=plot_n_col,
@@ -541,7 +554,8 @@ def analysis_ratio_distribution(self,
                                 difference_dist: bool = False,
                                 reference_group: str = "",
                                 as_boxplot: bool = False,
-                                as_subplots: bool = True) -> Tuple[plt.Figure, Dict[str, pd.DataFrame]]:
+                                as_subplots: bool = True,
+                                z_scores: bool = False) -> Tuple[plt.Figure, Dict[str, pd.DataFrame]]:
     """
     TODO: Tim
     :param enzyme_subset: list, default None, if given only reactions with the given enzymes are plotted
@@ -558,6 +572,7 @@ def analysis_ratio_distribution(self,
     :param as_boxplot: boolean, default False, whether to plot ratios as boxplots or histograms (if False)
     :param as_subplots: boolean default True, if False and as_boxplot is True all reactions will be plotted in a
                         single plot with one reaction per position on the x-axis
+    :param z_scores: boolean, default False, whether to scale ratios to zero mean and unit variance (over all groups)
     :return: 2-tuple, plt.Figure containing histograms and a dictionary of data frames containing ratio distributions
     """
     if (not hasattr(self, "groups") or self.groups is None) and difference_dist:
@@ -577,7 +592,8 @@ def analysis_ratio_distribution(self,
         self, g, l_mapping, enzyme_subset,
         difference_as_change, distribution_per_sample, select_groups,
         fa_specific, plot_n_col, plot_fig_size, plot_hspace,
-        difference_dist, reference_group, as_boxplot, as_subplots
+        difference_dist, reference_group, as_boxplot, as_subplots,
+        z_scores=z_scores
     )
 
 
@@ -594,7 +610,8 @@ def analysis_enrichment_ratio_plots(
     difference_dist: bool = False,
     reference_group: str = "",
     as_boxplot: bool = False,
-    as_subplots: bool = True
+    as_subplots: bool = True,
+    z_scores: bool = True
 ) -> Tuple[plt.Figure, Dict[str, pd.DataFrame]]:
     """
     :param enrichment_network: nx.Graph, enriched subnetwork as returned by
@@ -612,6 +629,7 @@ def analysis_enrichment_ratio_plots(
     :param as_boxplot: boolean, default False, whether to plot ratios as boxplots or histograms (if False)
     :param as_subplots: boolean default True, if False and as_boxplot is True all reactions will be plotted in a
                         single plot with one reaction per position on the x-axis
+    :param z_scores: boolean, default False, whether to scale ratios to zero mean and unit variance (over all groups)
     :return: 2-tuple, plt.Figure containing histograms and a dictionary of data frames containing ratio distributions
     """
     if (not hasattr(self, "groups") or self.groups is None) and difference_dist:
@@ -634,7 +652,8 @@ def analysis_enrichment_ratio_plots(
         self, cleaned_network, lipid_mapping, None,
         difference_as_change, distribution_per_sample, select_groups,
         fa_specific, plot_n_col, plot_fig_size, plot_hspace,
-        difference_dist, reference_group, as_boxplot, as_subplots
+        difference_dist, reference_group, as_boxplot, as_subplots,
+        z_scores=z_scores
     )
 
 
@@ -786,3 +805,4 @@ def analysis_lipid_substructure(self, combined: bool = False) -> pd.DataFrame:
         return feature_matrix.dot(self.data).append(self.data)
     else:
         return feature_matrix.dot(self.data)
+
