@@ -79,7 +79,12 @@ class Extender:
                      reference_lipids: List[ReferenceLipid] = None) -> Edgelist:
         # Class reactions
         tmp1 = self.evaluate_class_reactions(lip_dict)
-        stid = tmp1.raw_edgelist_copy()[-1].get_reaction_id()
+        tmp1_ed = tmp1.raw_edgelist_copy()
+        if len(tmp1_ed) > 0:
+            stid = tmp1.raw_edgelist_copy()[-1].get_reaction_id()
+        else:
+            stid = 0
+        # stid = tmp1.raw_edgelist_copy()[-1].get_reaction_id()
         # FA reactions
         tmp2 = self.evaluate_fa_reactions(lip_dict, excluded_fa_conversions, startid=int(stid)+1)
         tmp2_ed = tmp2.raw_edgelist_copy()
@@ -101,8 +106,6 @@ class Extender:
         tmp2 = self.evaluate_fa_reactions_parallel(lip_dict, n_processes, excluded_fa_conversions)
         return tmp1 + tmp2
 
-        return  tmp1 + tmp2
-
 
 def lfad22_inner(i: Reaction, r1: List[Lipid], l1: Lipid, l2: Lipid, l3: Lipid, rid: int = 0) -> List[Edge]:
     for l4 in r1:
